
--- Add the handler to an object for the event named eventName.
--- Note: only API components and objects with the AddListener function can be called.
---@param obj any
---@param eventName string
---@param handler function
local function AddListener(obj, eventName, handler) end

--- Removes the handler to an object for the event named eventName, which inverses the call to AddListener.
--- Note: only API components and objects with the RemoveListener method can be called.
---@param obj any
---@param eventName string
---@param handler function
local function RemoveListener(obj, eventName, handler) end

--- Calls each handler added as the event handler.
--- Note: only objects with the Emit method can be called.
---@param obj any
---@param eventName string
---@param ... any other arguments
local function Emit(obj, eventName, ...) end

EventHelper = {
    AddListener = AddListener,
    RemoveListener = RemoveListener,
    Emit = Emit,
}

