---@class Object
Object = Class()
---@class Exception
Exception = Class()
---@class Type
Type = Class()

---@class AbstractHybridYaComponent
AbstractHybridYaComponent = Class()

---@class YaForcerComponent : AbstractHybridYaComponent
YaForcerComponent = Class()
---@param speed number
function YaForcerComponent:SetSpeed(speed) end
---@param force number
function YaForcerComponent:SetForce(force) end
---@param direction float3
function YaForcerComponent:SetDirection(direction) end
---@return number
function YaForcerComponent:GetSpeed() end
---@return number
function YaForcerComponent:GetForce() end
---@return float3
function YaForcerComponent:GetDirection() end

---@class YaMoverComponent : AbstractHybridYaComponent
YaMoverComponent = Class()
--- / 
---@param play boolean @/
function YaMoverComponent:PlayMoving(play) end
--- 
---@param speed number @
function YaMoverComponent:SetMoveSpeed(speed) end
--- 
---@return number
function YaMoverComponent:GetMoveSpeed() end
--- 
---@param TargetPosition float3
---@param isLocal boolean
function YaMoverComponent:SetTargetPosition(TargetPosition,isLocal) end
--- 
---@param TargetPosition float3
function YaMoverComponent:SetTargetPosition(TargetPosition) end
--- 
---@return float3
function YaMoverComponent:GetTargetPosition() end
---@type fun() @
YaMoverComponent.StartMoving = value()
---@type fun() @
YaMoverComponent.StopMoving = value()
---@type fun() @
YaMoverComponent.FinishMoving = value()

---@class YaPendulumComponent : AbstractHybridYaComponent
YaPendulumComponent = Class()
--- / 
---@param play boolean @/
function YaPendulumComponent:PlayMoving(play) end
--- 
---@param speed number @
function YaPendulumComponent:SetSpeed(speed) end
--- 
---@return number
function YaPendulumComponent:GetSpeed() end
--- 
---@param point float3 @
---@param isLocal boolean
function YaPendulumComponent:SetCenterPoint(point,isLocal) end
--- 
---@param point float3 @
function YaPendulumComponent:SetCenterPoint(point) end
--- 
---@return float3
function YaPendulumComponent:GetCenterPoint() end
--- 
---@param aix float3 @
---@param isLocal boolean
function YaPendulumComponent:SetRotateAix(aix,isLocal) end
--- 
---@param aix float3 @
function YaPendulumComponent:SetRotateAix(aix) end
--- 
---@return float3
function YaPendulumComponent:GetRotateAix() end
---  
---@param TargetPosition number
function YaPendulumComponent:SetTargetAngle(TargetPosition) end
---  
---@return number
function YaPendulumComponent:GetTargetAngle() end
---@type fun() @
YaPendulumComponent.StartMoving = value()
---@type fun() @
YaPendulumComponent.StopMoving = value()
---@type fun() @
YaPendulumComponent.FinishMoving = value()

---@class YaSpinnerComponent : AbstractHybridYaComponent
YaSpinnerComponent = Class()
--- / 
---@param play boolean @/
function YaSpinnerComponent:PlayMoving(play) end
--- 
---@param speed number @
function YaSpinnerComponent:SetRotateSpeed(speed) end
--- 
---@return number
function YaSpinnerComponent:GetRotateSpeed() end
---  
---@param angle number
function YaSpinnerComponent:SetTargetAngle(angle) end
--- 
---@return number
function YaSpinnerComponent:GetTargetAngle() end
---@type fun() @
YaSpinnerComponent.StartRotate = value()
---@type fun() @
YaSpinnerComponent.StopRotate = value()
---@type fun() @
YaSpinnerComponent.FinishRotate = value()

---@class YaSoundProviderComponent : AbstractHybridYaComponent
YaSoundProviderComponent = Class()
--- Return current clip's length.
---@return number
function YaSoundProviderComponent:GetClipLength() end
--- Set Track length.
---@param length number
function YaSoundProviderComponent:SetClipLength(length) end
--- Set the "volume"  as the sound volume,which ranges in [0-1f].
---@param volume number @Sound Volume.
function YaSoundProviderComponent:SetVolume(volume) end
--- Get the "volume" ,which ranges in [0-1f].
---@return number
function YaSoundProviderComponent:GetVolume() end
--- ToDo Api,which allow "Sound Provider" can play different sound clip.
---@param musicID string
function YaSoundProviderComponent:ChangeSong(musicID) end
--- Return "Sound Provider" whether is playing clip or not.
---@return boolean
function YaSoundProviderComponent:IsPlaying() end
---@return number
function YaSoundProviderComponent:GetSoundId() end
--- Make "Sound Provider" play from last track point.
function YaSoundProviderComponent:Play() end
--- Make "Sound Provider" play from head of the track.
function YaSoundProviderComponent:Replay() end
--- Make "Sound Provider" pause from playing.
function YaSoundProviderComponent:Pause() end
--- Set Sound 3D
---@param isThreeDimension boolean
function YaSoundProviderComponent:SetThreeDimensionalSound(isThreeDimension) end
--- Set Max Min Distance
---@param minValue number
---@param maxValue number
function YaSoundProviderComponent:SetMinMaxDistance(minValue,maxValue) end
--- Set Loop
---@param Looping boolean
function YaSoundProviderComponent:SetSoundLoop(Looping) end
--- Get Loop
---@return boolean
function YaSoundProviderComponent:GetSoundLoop() end

---@class YaEntity
YaEntity = Class()
---@return boolean
function YaEntity:IsNull() end
---@param other YaEntity
---@return boolean
function YaEntity:Equals(other) end
---@return number
function YaEntity:GetHashCode() end
---@type number
YaEntity.UninitializedEntityId = value()
---@type YaEntity
YaEntity.Null = value()
---@type number
YaEntity.EntityId = value()

---@class TraceMode
TraceMode = Class()
---@type TraceMode
TraceMode.NeverTrace = value()
---@type TraceMode
TraceMode.StopWhenReach = value()
---@type TraceMode
TraceMode.StopWhenTimeOut = value()
---@type TraceMode
TraceMode.ReStartAfterStop = value()

---@class YaTraceMoverComponent : YaMoverComponent
YaTraceMoverComponent = Class()
---@param targetEntity YaEntity
---@param speed number
---@param traceMode TraceMode
---@param offset float3
---@param maxTraceTime number
function YaTraceMoverComponent:StartTrace(targetEntity,speed,traceMode,offset,maxTraceTime) end
---@param targetEntity YaEntity
---@param speed number
---@param traceMode TraceMode
---@param offset float3
function YaTraceMoverComponent:StartTrace(targetEntity,speed,traceMode,offset) end
---@param targetEntity YaEntity
---@param speed number
---@param traceMode TraceMode
function YaTraceMoverComponent:StartTrace(targetEntity,speed,traceMode) end
function YaTraceMoverComponent:EndTrace() end
---@type fun() @Publish when tracer reach the target
YaTraceMoverComponent.TracerReachTarget = value()

---@class YaInteractableComponent : AbstractHybridYaComponent
YaInteractableComponent = Class()
function YaInteractableComponent:EnableInteractable() end
function YaInteractableComponent:DisableInteractable() end
--- Set Interactive Range for Lua
---@param radius number
---@param hight number
function YaInteractableComponent:SetInteractiveRange(radius,hight) end
---@type fun(v0: YaEntity) @
YaInteractableComponent.PlayerContactEvent = value()
---@type fun(v0: YaEntity) @
YaInteractableComponent.PlayerLeaveEvent = value()
