"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deactivate = exports.activate = void 0;
const path = require("path");
const fs = require("fs");
const AdmZip = require("adm-zip");
const vscode = require("vscode");
const MobdebugProvider_1 = require("./MobdebugProvider");
function activate(context) {
    console.log('[yahahaluadebugger] activated');
    attachAnnotation();
    const mobdebugProvider = new MobdebugProvider_1.MobdebugProvider(context);
    context.subscriptions.push(vscode.debug.registerDebugConfigurationProvider("yahaha_lua_mobdebug", mobdebugProvider));
    context.subscriptions.push(mobdebugProvider);
    context.subscriptions.push(vscode.debug.onDidTerminateDebugSession(_s => {
        console.log(`debug session terminated`);
    }));
    context.subscriptions.push(vscode.commands.registerCommand('yahaha.pack.component', (uri) => {
        const done = packComponent(uri.fsPath);
        if (done) {
            vscode.window.showInformationMessage(`Pack successfully!`);
        }
    }));
}
exports.activate = activate;
function deactivate() {
    console.log('[yahahaluadebugger] deactivated');
    detachAnnotation();
}
exports.deactivate = deactivate;
function attachAnnotation() {
    const annoationPath = getAnnotation();
    const luaConfig = vscode.workspace.getConfiguration("Lua", null);
    if (luaConfig) {
        const library = luaConfig.get("workspace.library");
        if (annoationPath && library) {
            if (library.indexOf(annoationPath) === -1) {
                library.push(annoationPath);
                luaConfig.update("workspace.library", library, true);
                const size = luaConfig.get("workspace.preloadFileSize") || 0;
                if (size < 300) {
                    luaConfig.update("workspace.preloadFileSize", 300, true);
                }
            }
        }
    }
}
function detachAnnotation() {
    const annoationPath = getAnnotation();
    const luaConfig = vscode.workspace.getConfiguration("Lua", null);
    if (luaConfig) {
        const library = luaConfig.get("workspace.library");
        if (annoationPath && library) {
            const index = library.indexOf(annoationPath);
            if (index !== -1) {
                library.splice(index, 1);
                luaConfig.update("workspace.library", library, true);
            }
        }
    }
}
function getAnnotation() {
    const extensionId = "yahaha.yahahaluadebugger";
    const extensionPath = vscode.extensions.getExtension(extensionId)?.extensionPath;
    return extensionPath ? path.join(extensionPath, "annotation") : "";
}
function packComponent(dir) {
    if (validateComponentDir(dir)) {
        const pkg = require(path.join(dir, "package.json"));
        const zip = new AdmZip();
        zip.addFile(pkg.xml, fs.readFileSync(path.join(dir, pkg.xml)));
        zip.addFile(pkg.tpl, fs.readFileSync(path.join(dir, pkg.tpl)));
        if (!pkg.version) {
            pkg.version = "0.0.1";
        }
        const json = JSON.stringify(pkg, null, 4);
        zip.addFile("package.json", Buffer.from(json, "utf8"));
        zip.writeZip(path.join(dir, pkg.name + '.ygc'));
        return true;
    }
    return false;
}
function validateComponentDir(dir) {
    let valid = true;
    const pkgPath = path.join(dir, "package.json");
    if (!fs.existsSync(pkgPath)) {
        valid = false;
        vscode.window.showErrorMessage('unable to locate package.json');
        console.error('unable to locate package.json');
    }
    else {
        try {
            const pkg = require(pkgPath);
            return validatePackage(dir, pkg);
        }
        catch {
            vscode.window.showErrorMessage('package.json invalid');
            console.error('package.json invalid');
            valid = false;
        }
    }
    return valid;
}
function validatePackage(dir, pkg) {
    let valid = true;
    if (!pkg) {
        vscode.window.showErrorMessage('[package.json] content is empty');
        console.error('[package.json] content is empty');
        return false;
    }
    if (!pkg.name) {
        valid = false;
        vscode.window.showErrorMessage('[package.json] name is required');
        console.error('[package.json] name is required');
    }
    if (!pkg.publisher) {
        valid = false;
        vscode.window.showErrorMessage('[package.json] publisher is required');
        console.error('[package.json] publisher is required');
    }
    if (!pkg.xml) {
        valid = false;
        vscode.window.showErrorMessage('[package.json] xml is required');
        console.error('[package.json] xml is required');
    }
    else if (!fs.existsSync(path.join(dir, pkg.xml))) {
        valid = false;
        vscode.window.showErrorMessage('[package.json] unable to locate ' + pkg.xml);
        console.error('[package.json] unable to locate ' + pkg.xml);
    }
    else {
        const content = fs.readFileSync(path.join(dir, pkg.xml));
        if (content.length === 0) {
            valid = false;
            vscode.window.showErrorMessage('[package.json] ' + pkg.xml + ' content is empty');
            console.error('[package.json] ' + pkg.xml + ' content is empty');
        }
    }
    if (!pkg.tpl) {
        valid = false;
        vscode.window.showErrorMessage('[package.json] tpl is required');
        console.error('[package.json] tpl is required');
    }
    else if (!fs.existsSync(path.join(dir, pkg.tpl))) {
        valid = false;
        vscode.window.showErrorMessage('[package.json] unable to locate ' + pkg.tpl);
        console.error('[package.json] unable to locate ' + pkg.tpl);
    }
    return valid;
}
//# sourceMappingURL=extension.js.map