"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AsyncBlockingQueue = void 0;
class AsyncBlockingQueue {
    constructor(maxSize = 0) {
        this.queue = [];
        this.blockedEnqueue = [];
        this.blockedDequeue = [];
        this.maxSize = maxSize;
    }
    isFull() {
        return this.maxSize > 0 && this.queue.length >= this.maxSize;
    }
    enqueue(o) {
        // notify one dequeue callback,
        // or save it if there is no dequeue callback
        const cr = this.blockedDequeue.shift();
        if (cr !== undefined) {
            cr[0](o);
        }
        else {
            this.queue.push(o);
        }
        if (this.isFull()) { // full, let's take a break
            return new Promise(c => this.blockedEnqueue.push(c));
        }
        else { // still vacant, keep working
            return Promise.resolve();
        }
    }
    dequeue() {
        const o = this.queue.shift();
        if (o !== undefined) { // not empty
            // notify all blocking enqueue, if not full
            if (!this.isFull()) {
                this.awakeBlockedEnqueue();
            }
            return Promise.resolve(o);
        }
        else { // empty, just wait in queue
            return new Promise((c, r) => this.blockedDequeue.push([c, r]));
        }
    }
    awakeBlockedEnqueue() {
        if (this.blockedEnqueue.length > 0) {
            this.blockedEnqueue.forEach(cb => cb());
            this.blockedEnqueue = [];
        }
    }
    releaseBlockedEnqueue() {
        this.awakeBlockedEnqueue();
    }
    releaseBlockedDequeue(reason) {
        if (this.blockedDequeue.length > 0) {
            this.blockedDequeue.forEach(cr => cr[1](reason));
            this.blockedDequeue = [];
        }
    }
}
exports.AsyncBlockingQueue = AsyncBlockingQueue;
//# sourceMappingURL=AsyncBlockingQueue.js.map